==> qtwebengine-opensource-src_5.12.8+dfsg.orig.tar.xz: qtwebengine-everywhere-src-5.12.8/src/3rdparty/chromium/components/password_manager/core/browser/password_store_signin_notifier.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_
#define COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_

#include <string>

#include "base/macros.h"
#include "base/strings/utf_string_conversions.h"

namespace password_manager {

class PasswordStore;

// Abstract class for notifying PasswordStore about Chrome sign-in events.
// The logic of receiving sign-in events and notifying PasswordStore is split
// in the base abstract class (this class, in components/) and an
// implementation (in the chrome/browser/), because components/ doesn't know
// anything about Chrome sign-in.
class PasswordStoreSigninNotifier {
 public:
  PasswordStoreSigninNotifier();
  virtual ~PasswordStoreSigninNotifier();

  virtual void SubscribeToSigninEvents(PasswordStore* store) = 0;
  virtual void UnsubscribeFromSigninEvents() = 0;

 protected:
  void set_store(PasswordStore* store) { store_ = store; }

  // Passes sign-in to |store_|.
  void NotifySignin(const std::string& username, const std::string& password);

  // Passes signed-out to |store_|.
  void NotifySignedOut(const std::string& username);

 private:
  PasswordStore* store_ = nullptr;  // weak

  DISALLOW_COPY_AND_ASSIGN(PasswordStoreSigninNotifier);
};

}  // namespace password_manager

#endif  // COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_

==> qtwebengine-opensource-src_5.15.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-5.15.2/src/3rdparty/chromium/components/password_manager/core/browser/password_store_signin_notifier.h <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_
#define COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_

#include <string>
#include <vector>

#include "base/macros.h"
#include "base/strings/utf_string_conversions.h"

namespace autofill {
struct PasswordForm;
}

namespace password_manager {

class PasswordStore;

// Abstract class used by PasswordStore to receive/send notifications about
// Chrome sign-in/sign-out events.
// The logic of receiving sign-in events and notifying PasswordStore is split
// in the base abstract class (this class, in components/) and an
// implementation (in the chrome/browser/), because components/ doesn't know
// anything about Chrome sign-in/sign-out.
class PasswordStoreSigninNotifier {
 public:
  PasswordStoreSigninNotifier();
  virtual ~PasswordStoreSigninNotifier();

  virtual void SubscribeToSigninEvents(PasswordStore* store) = 0;
  virtual void UnsubscribeFromSigninEvents() = 0;
  virtual void NotifyUISignoutWillDeleteCredentials(
      const std::vector<autofill::PasswordForm>& unsynced_credentials) = 0;

 protected:
  void set_store(PasswordStore* store) { store_ = store; }

  // Passes signed-out to |store_|.
  void NotifySignedOut(const std::string& username, bool primary_account);

 private:
  PasswordStore* store_ = nullptr;  // weak

  DISALLOW_COPY_AND_ASSIGN(PasswordStoreSigninNotifier);
};

}  // namespace password_manager

#endif  // COMPONENTS_PASSWORD_MANAGER_CORE_BROWSER_PASSWORD_STORE_SIGNIN_NOTIFIER_H_
